abacusai.drift_distribution — AbacusAI documentation

# abacusai.drift_distribution

## Classes

`DriftDistribution` | How actuals or predicted values have changed in the training data versus predicted data

## Module Contents

class abacusai.drift_distribution.DriftDistribution(client, trainColumn=None, predictedColumn=None, metrics=None, distribution={})

  Bases: `abacusai.return_class.AbstractApiClass`

  How actuals or predicted values have changed in the training data versus predicted data

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - trainColumn (str) – The feature name in the train table.

    - predictedColumn (str) – The feature name in the prediction table.

    - metrics (dict) – Drift measures.

    - distribution (FeatureDistribution) – A FeatureDistribution, how the training data compares to the predicted data.

  train_column = None
  predicted_column = None
  metrics = None
  distribution
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict